OneFeaturedIconSize enum

Inheritance
Available extensions

Values

sm → const OneFeaturedIconSize
md → const OneFeaturedIconSize
lg → const OneFeaturedIconSize
xl → const OneFeaturedIconSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double

Available on OneFeaturedIconSize, provided by the OneFeaturedIconSizeExtension extension

no setter

Methods

borderRadius(OneFeaturedIconType type) double

Available on OneFeaturedIconSize, provided by the OneFeaturedIconSizeExtension extension

iconSize(OneFeaturedIconType type) double

Available on OneFeaturedIconSize, provided by the OneFeaturedIconSizeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OneFeaturedIconSize>
A constant List of the values in this enum, in order of their declaration.